#[repr(u32)]pub enum PixelFormat {
Mono8 = 17_301_505,
Mono16 = 17_825_799,
BayerRG8 = 17_301_513,
BayerGB8 = 17_301_514,
BayerBG8 = 17_301_515,
BayerGR8 = 17_301_512,
RGB8Packed = 35_127_316,
BGR8Packed = 35_127_317,
Unknown(u32),
}Expand description
Enumeration of the pixel formats supported by the helper routines.
Variants
Mono8 = 17_301_505
Mono16 = 17_825_799
BayerRG8 = 17_301_513
BayerGB8 = 17_301_514
BayerBG8 = 17_301_515
BayerGR8 = 17_301_512
RGB8Packed = 35_127_316
BGR8Packed = 35_127_317
Unknown(u32)
Unknown PFNC code reported by the device.
Implementations
Sourceimpl PixelFormat
impl PixelFormat
Sourcepub const fn from_code(code: u32) -> PixelFormat
pub const fn from_code(code: u32) -> PixelFormat
Convert a raw PFNC code into a PixelFormat enumeration.
Sourcepub const fn bytes_per_pixel(self) -> Option<usize>
pub const fn bytes_per_pixel(self) -> Option<usize>
Number of bytes used to encode a single pixel for well-known formats.